package com.twelvemonkeys.imageio.stream;

import javax.imageio.spi.ImageInputStreamSpi;
import javax.imageio.stream.ImageInputStream;
import javax.imageio.stream.ImageInputStreamImpl;
import java.io.File;
import java.io.IOException;
import java.util.Locale;

/**
 * ByteArrayImageInputStreamSpi
 * Experimental
 *
 * @author <a href="mailto:harald.kuhr@gmail.com">Harald Kuhr</a>
 * @author last modified by $Author: haraldk$
 * @version $Id: ByteArrayImageInputStreamSpi.java,v 1.0 May 15, 2008 2:12:12 PM haraldk Exp$
 */
public class ByteArrayImageInputStreamSpi extends ImageInputStreamSpi {

    public ByteArrayImageInputStreamSpi() {
        super("TwelveMonkeys", "1.0 BETA", byte[].class);
    }

    public ImageInputStream createInputStreamInstance(Object pInput, boolean pUseCache, File pCacheDir) throws IOException {
        if (pInput instanceof byte[]) {
            return new ByteArrayImageInputStream((byte[]) pInput);
        }
        else {
            throw new IllegalArgumentException("Expected input of type byte[]: " + pInput);
        }
    }

    public String getDescription(Locale pLocale) {
        return "Service provider that instantiates an ImageInputStream from a byte array";
    }

    /**
     * Experimental
     */
    public static final class ByteArrayImageInputStream extends ImageInputStreamImpl {
        private final byte[] mData;

        public ByteArrayImageInputStream(final byte[] pData) {
            mData = pData;
        }

        public int read() throws IOException {
            if (streamPos >= mData.length) {
                return -1;
            }
            bitOffset = 0;
            return mData[((int) streamPos++)] & 0xff;
        }

        public int read(byte[] pBuffer, int pOffset, int pLength) throws IOException {
            if (streamPos >= mData.length) {
                return -1;
            }
            int length = (int) Math.min(mData.length - streamPos, pLength);
            bitOffset = 0;
            System.arraycopy(mData, (int) streamPos, pBuffer, pOffset, length);
            streamPos += length;
            return length;
        }

        @Override
        public long length() {
            return mData.length;
        }

        @Override
        public int skipBytes(int n) throws IOException {
            return super.skipBytes(n);
        }

        @Override
        public boolean isCached() {
            return true;
        }

        @Override
        public boolean isCachedMemory() {
            return true;
        }
    }
}
